( cd usr/X11R6/bin ; rm -rf fvwm )
( cd usr/X11R6/bin ; ln -sf fvwm2 fvwm )
( cd usr/X11R6/bin ; rm -rf fvwm-root )
( cd usr/X11R6/bin ; ln -sf xpmroot fvwm-root )
( cd usr/X11R6/lib/X11 ; rm -rf fvwm2 )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/fvwm2 fvwm2 )
( cd usr/X11R6/man/man1 ; rm -rf fvwm-root.1 )
( cd usr/X11R6/man/man1 ; ln -sf xpmroot.1 fvwm-root.1 )
( cd usr/X11R6/man/man1 ; rm -rf fvwm.1 )
( cd usr/X11R6/man/man1 ; ln -sf fvwm2.1 fvwm.1 )
( cd usr/X11R6/libexec/fvwm/2.4.16 ; rm -rf FvwmAudio )
( cd usr/X11R6/libexec/fvwm/2.4.16 ; ln -sf FvwmEvent FvwmAudio )
